@@ -46,7 +46,10 @@ class Processing(AindCoreModel):
     """Desription of all processes run on data"""
 
     schema_version: str = Field(
-        "0.1.0", description="Schema version", title="Schema version", const=True,
+        "0.1.0",
+        description="Schema version",
+        title="Schema version",
+        const=True,
     )
     pipeline_version: Optional[str] = Field(None, description="Version of the pipeline", title="Pipeline version")
     pipeline_url: Optional[str] = Field(None, description="URL to the pipeline code", title="Pipeline URL")
