@@ -5,8 +5,8 @@ import unittest
 
 from pydantic import ValidationError
 
-from aind_data_schema import Acquisition, Instrument
-from aind_data_schema.imaging.acquisition import Axis
+from aind_data_schema.imaging import acquisition as acq
+from aind_data_schema.imaging import instrument as inst
 
 
 class ImagingTests(unittest.TestCase):
@@ -15,24 +15,38 @@ class ImagingTests(unittest.TestCase):
     def test_constructors(self):
         """testing constructors"""
         with self.assertRaises(ValidationError):
-            a = Acquisition()
+            a = acq.Acquisition()
 
-        a = Acquisition(
+        a = acq.Acquisition(
             experimenter_full_name="alice",
             session_start_time=datetime.datetime.now(),
             subject_id="1234",
             instrument_id="1234",
             session_end_time=datetime.datetime.now(),
-            positions=[],
-            channels=[],
+            chamber_immersion=acq.Immersion(medium="PBS", refractive_index=1),
+            tiles=[
+                acq.Tile(
+                    coordinate_transformations=[
+                        acq.Scale3dTransform(scale=[1, 1, 1]),
+                        acq.Translation3dTransform(translation=[1, 1, 1]),
+                    ],
+                    channel=acq.Channel(
+                        channel_name="488",
+                        laser_wavelength=488,
+                        laser_power=0.1,
+                        filter_wheel_index=0,
+                    ),
+                )
+            ],
+            axes=[],
         )
 
         assert a is not None
 
         with self.assertRaises(ValidationError):
-            i = Instrument()
+            i = inst.Instrument()
 
-        i = Instrument(
+        i = inst.Instrument(
             type="smartSPIM",
             location="440",
             manufacturer="LifeCanvas",
@@ -45,13 +59,10 @@ class ImagingTests(unittest.TestCase):
 
     def test_axis(self):
         """test the axis class"""
-        voxel_sizes = [1, 2, 3]
-        volume_sizes = [10, 10, 10]
-
         # test that a few work
         test_codes = ["RAS", "LSP", "RAI", "PAR"]
         for test_code in test_codes:
-            axes = Axis.from_direction_code(test_code, voxel_sizes, volume_sizes)
+            axes = acq.Axis.from_direction_code(test_code)
             assert len(axes) == 3
 
 
